@@ -311,10 +311,10 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
                 ydata = plot_obj.get_ydata()
                 X = xdata[ind][0]  # X position of the click
                 Y = ydata[ind][0]  # Y position of the click
-                if self.fig.legend() not in [None, []]:
-                    legend = (
-                        self.fig.legend().texts[self.ax.lines.index(plot_obj)]._text
-                    )
+                if self.ax.get_legend_handles_labels()[1] != []:
+                    legend = self.ax.get_legend_handles_labels()[1][
+                        self.ax.lines.index(plot_obj)
+                    ]
             elif isinstance(plot_obj, PathCollection):
                 ind = event.ind
                 X = plot_obj.get_offsets().data[ind][0][0]
@@ -550,5 +550,6 @@ class DDataPlotter(Ui_DDataPlotter, QWidget):
     def showEvent(self, ev):
         super(DDataPlotter, self).showEvent(ev)
         self.w_scroll.setFixedWidth(
-            500 + self.w_scroll.verticalScrollBar().sizeHint().width()
+            498 + self.w_scroll.verticalScrollBar().sizeHint().width()
         )
+        self.w_scroll.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
